@@ -1,9 +1,11 @@
 import jwt
 import time
-from .conf import CENTRIFUGO_HMAC_KEY
+
+from django.conf import settings
 
 
 def connection_token(user):
+    CENTRIFUGO_HMAC_KEY = getattr(settings, "CENTRIFUGO_HMAC_KEY", None)
     if CENTRIFUGO_HMAC_KEY is None:
         raise ValueError("Provide a CENTRIFUGO_HMAC_KEY in settings")
     claims = {"sub": user.username, "exp": int(time.time()) + 24 * 60 * 60}
@@ -12,6 +14,7 @@ def connection_token(user):
 
 
 def channel_token(client, channel):
+    CENTRIFUGO_HMAC_KEY = getattr(settings, "CENTRIFUGO_HMAC_KEY", None)
     if CENTRIFUGO_HMAC_KEY is None:
         raise ValueError("Provide a CENTRIFUGO_HMAC_KEY in settings")
     claims = {
